==> members-facade-1.0.1-20181220.101604-72-sources.jar: com/bizvane/members/facade/models/MbrDefinedGroupModel.java <==
package com.bizvane.members.facade.models;

import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/**
 * @Author: houkai
 * @Date: 2018/11/26 14:22
 * @Description:
 */
@Data
@Table(name = "t_mbr_defined_group")
public class MbrDefinedGroupModel extends BaseModel implements Serializable {
    private static final long serialVersionUID = -8812824018835835332L;

    /**
     * 只读.
     * 主键id. defined_group_id
     *
     * @mbg.generated 2018-11-26 15:53:25
     */
    @Id
    @ApiModelProperty(value = "主键id", name = "definedGroupId", required = false, example = "主键id")
    private Long definedGroupId;

    /**
     * 只读.
     * 企业id. sys_company_id
     *
     * @mbg.generated 2018-11-26 15:53:25
     */
    @ApiModelProperty(value = "企业id", name = "sysCompanyId", required = false, example = "企业id")
    private Long sysCompanyId;

    /**
     * 只读.
     * 品牌id. sys_brand_id
     *
     * @mbg.generated 2018-11-26 15:53:25
     */
    @ApiModelProperty(value = "品牌id", name = "sysBrandId", required = false, example = "品牌id")
    private Long sysBrandId;

    /**
     * 只读.
     * 店铺id. sys_store_id
     *
     * @mbg.generated 2018-11-26 15:53:25
     */
    @ApiModelProperty(value = "店铺id", name = "sysStoreId", required = false, example = "店铺id")
    private Long sysStoreId;

    /**
     * 只读.
     * 自定义分组code. group_code
     *
     * @mbg.generated 2018-11-26 15:53:25
     */
    @ApiModelProperty(value = "自定义分组code", name = "groupCode", required = false, example = "自定义分组code")
    private String groupCode;

    /**
     * 只读.
     * 自定义分组名. group_name
     *
     * @mbg.generated 2018-11-26 15:53:25
     */
    @ApiModelProperty(value = "自定义分组名", name = "groupName", required = false, example = "自定义分组名")
    private String groupName;

    /**
     * 只读.
     * 是否常用 1:常用 2:不常用. is_common
     *
     * @mbg.generated 2018-11-26 15:53:25
     */
    @ApiModelProperty(value = "是否常用 1:常用 2:不常用", name = "isCommon", required = false, example = "是否常用 1:常用 2:不常用")
    private Integer isCommon;

    /**
     * 只读.
     * 分组内会员个数. member_count
     *
     * @mbg.generated 2018-11-26 15:53:25
     */
    @ApiModelProperty(value = "分组内会员个数", name = "memberCount", required = false, example = "分组内会员个数")
    private Integer memberCount;

    /**
     * 只读.
     * 分组内会员code,多个会员code以逗号分割. member_codes
     *
     * @mbg.generated 2018-11-26 15:53:25
     */
    @ApiModelProperty(value = "分组内会员code,多个会员code以逗号分割", name = "memberCodes", required = false, example = "分组内会员code,多个会员code以逗号分割")
    private String memberCodes;

}

==> members-facade-2.0.0-20191017.030847-57-sources.jar: com/bizvane/members/facade/models/MbrDefinedGroupModel.java <==
package com.bizvane.members.facade.models;

import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/**
 * @Author: houkai
 * @Date: 2018/11/26 14:22
 * @Description:
 */
@Data
@Table(name = "t_mbr_defined_group")
public class MbrDefinedGroupModel extends BaseModel implements Serializable {
    private static final long serialVersionUID = -8812824018835835332L;

    /**
     * 只读.
     * 主键id. defined_group_id
     *
     * @mbg.generated 2018-11-26 15:53:25
     */
    @Id
    @ApiModelProperty(value = "主键id", name = "definedGroupId", required = false, example = "主键id")
    private Long definedGroupId;

    /**
     * 只读.
     * 企业id. sys_company_id
     *
     * @mbg.generated 2018-11-26 15:53:25
     */
    @ApiModelProperty(value = "企业id", name = "sysCompanyId", required = false, example = "企业id")
    private Long sysCompanyId;

    /**
     * 只读.
     * 品牌id. sys_brand_id
     *
     * @mbg.generated 2018-11-26 15:53:25
     */
    @ApiModelProperty(value = "品牌id", name = "sysBrandId", required = false, example = "品牌id")
    private Long sysBrandId;

    /**
     * 只读.
     * 店铺id. sys_store_id
     *
     * @mbg.generated 2018-11-26 15:53:25
     */
    @ApiModelProperty(value = "店铺id", name = "sysStoreId", required = false, example = "店铺id")
    private Long sysStoreId;

    /**
     * 只读.
     * 自定义分组code. group_code
     *
     * @mbg.generated 2018-11-26 15:53:25
     */
    @ApiModelProperty(value = "自定义分组code", name = "groupCode", required = false, example = "自定义分组code")
    private String groupCode;

    /**
     * 只读.
     * 自定义分组名. group_name
     *
     * @mbg.generated 2018-11-26 15:53:25
     */
    @ApiModelProperty(value = "自定义分组名", name = "groupName", required = false, example = "自定义分组名")
    private String groupName;

    /**
     * 只读.
     * 是否常用 1:常用 2:不常用. is_common
     *
     * @mbg.generated 2018-11-26 15:53:25
     */
    @ApiModelProperty(value = "是否常用 1:常用 2:不常用", name = "isCommon", required = false, example = "是否常用 1:常用 2:不常用")
    private Integer isCommon;

    /**
     * 只读.
     * 分组内会员个数. member_count
     *
     * @mbg.generated 2018-11-26 15:53:25
     */
    @ApiModelProperty(value = "分组内会员个数", name = "memberCount", required = false, example = "分组内会员个数")
    private Integer memberCount;

    /**
     * 只读.
     * 分组内会员code,多个会员code以逗号分割. member_codes
     *
     * @mbg.generated 2018-11-26 15:53:25
     */
    @ApiModelProperty(value = "分组内会员code,多个会员code以逗号分割", name = "memberCodes", required = false, example = "分组内会员code,多个会员code以逗号分割")
    private String memberCodes;


    @ApiModelProperty(value = "导购id", name = "createUserId", required = false, example = "导购id")
    private Long createUserId;
}
